@@ -383,7 +383,7 @@ Tk_UnmaintainGeometry(slave, master)
 	    }
 	}
 	if (masterPtr->checkScheduled) {
-	    Tk_CancelIdleCall(MaintainCheckProc, (ClientData) masterPtr);
+	    Tcl_CancelIdleCall(MaintainCheckProc, (ClientData) masterPtr);
 	}
 	Tcl_DeleteHashEntry(hPtr);
 	ckfree((char *) masterPtr);
@@ -425,7 +425,7 @@ MaintainMasterProc(clientData, eventPtr)
 	    || (eventPtr->type == CTK_UNMAP_EVENT)) {
 	if (!masterPtr->checkScheduled) {
 	    masterPtr->checkScheduled = 1;
-	    Tk_DoWhenIdle(MaintainCheckProc, (ClientData) masterPtr);
+	    Tcl_DoWhenIdle(MaintainCheckProc, (ClientData) masterPtr);
 	}
     } else if (eventPtr->type == CTK_DESTROY_EVENT) {
 	/*
